FileLogPrinter class

Printer to use in the printer field of Logger when instantiated.

Like the name says, it's to be used when printing logs into a file. It can be also used for printing into console.

Constructors

FileLogPrinter(String label)
A label is required for displaying who the logger is printing for.

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
Nome della classe che utilizza il logger istanziato.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
init() → void
inherited
log(LogEvent event) → List<String>
Is called every time a new LogEvent is sent and handles printing or storing the message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited